==> rubygem-mechanize-0.7.8.tbz: lib/ruby/gems/1.8/gems/mechanize-0.7.8/test/test_authenticate.rb <==
require File.dirname(__FILE__) + "/helper"

class BasicAuthTest < Test::Unit::TestCase
  def setup
    @agent = WWW::Mechanize.new
  end

  def test_auth_success
    @agent.basic_auth('user', 'pass')
    page = @agent.get("http://localhost/basic_auth")
    assert_equal('You are authenticated', page.body)
  end

  def test_post_auth_success
    class << @agent
      alias :old_fetch_request :fetch_request
      attr_accessor :requests
      def fetch_request(*args)
        @requests ||= []
        @requests << old_fetch_request(*args)
        @requests.last
      end
    end
    @agent.basic_auth('user', 'pass')
    page = @agent.post("http://localhost/basic_auth")
    assert_equal('You are authenticated', page.body)
    assert_equal(2, @agent.requests.length)
    r1 = @agent.requests[0]
    r2 = @agent.requests[1]
    assert r1['Content-Type']
    assert r2['Content-Type']
    assert_equal(r1['Content-Type'], r2['Content-Type'])

    assert r1['Content-Length']
    assert r2['Content-Length']
    assert_equal(r1['Content-Length'], r2['Content-Length'])
  end

  def test_auth_bad_user_pass
    @agent.basic_auth('aaron', 'aaron')
    begin
      page = @agent.get("http://localhost/basic_auth")
    rescue WWW::Mechanize::ResponseCodeError => e
      assert_equal("401", e.response_code)
    end
  end

  def test_auth_failure
    begin
      page = @agent.get("http://localhost/basic_auth")
    rescue WWW::Mechanize::ResponseCodeError => e
      assert_equal("401", e.response_code)
    end
  end

end

==> rubygem-mechanize-1.0.0_1.tbz: lib/ruby/gems/1.8/gems/mechanize-1.0.0/test/test_authenticate.rb <==
require "helper"
require 'pp'

class BasicAuthTest < Test::Unit::TestCase
  def setup
    @agent = Mechanize.new
  end

  def test_auth_success
    @agent.basic_auth('user', 'pass')
    page = @agent.get("http://localhost/basic_auth")
    assert_equal('You are authenticated', page.body)
  end

  def test_digest_auth_success
    @agent.basic_auth('user', 'pass')
    page = @agent.get("http://localhost/digest_auth")
    assert_equal('You are authenticated', page.body)
  end

  def test_no_duplicate_headers
    block_called = false
    @agent.pre_connect_hooks << lambda { |params|
      block_called = true
      params[:request].to_hash.each do |k,v|
        assert_equal(1, v.length)
      end
    }
    @agent.basic_auth('user', 'pass')
    page = @agent.get("http://localhost/digest_auth")
    assert block_called
  end

  def test_post_auth_success
    class << @agent
      alias :old_fetch_page :fetch_page
      attr_accessor :requests
      def fetch_page(args)
        @requests ||= []
        x = old_fetch_page(args)
        @requests << args[:verb]
        x
      end
    end
    @agent.basic_auth('user', 'pass')
    page = @agent.post("http://localhost/basic_auth")
    assert_equal('You are authenticated', page.body)
    assert_equal(2, @agent.requests.length)
    r1 = @agent.requests[0]
    r2 = @agent.requests[1]
    assert_equal(r1, r2)
  end

  def test_auth_bad_user_pass
    @agent.basic_auth('aaron', 'aaron')
    begin
      page = @agent.get("http://localhost/basic_auth")
    rescue Mechanize::ResponseCodeError => e
      assert_equal("401", e.response_code)
    end
  end

  def test_auth_failure
    begin
      page = @agent.get("http://localhost/basic_auth")
    rescue Mechanize::ResponseCodeError => e
      assert_equal("401", e.response_code)
    end
  end

end
